import Vue from 'vue';
import Vuex from 'vuex';
import { validate, login } from '../api'

Vue.use(Vuex);

const store = new Vuex.Store({
  state: {
    username: '',
    loading: false
  },
  mutations: {
    setUsername(state, name) {
      state.username = name
    },
    setLoading(state, isShow) {
      state.loading = isShow
    }
  },
  actions: {
    async validate({ commit }) {
      let result

      try {
        result = await validate()
      } catch (err) {
        return false
      }

      if (result.code === 1) {
        return false
      }

      localStorage.setItem('token', result.token)
      commit('setUsername', result.username)
      return true
    },
    async login({ commit }, username) {
      const result = await login(username)

      if (result.code === 1) {
        return Promise.reject(result)
      }

      localStorage.setItem('token', result.token)
      commit('setUsername', result.username)
    }
  },
  modules: {
  }
});

Vue.prototype.$store = store
export default store
